import os
from jinjaql.factory import JinJAQL
import jinjaql.engine as engine
import pathlib
import pandas as pd
import pyodbc
import timeit

def nwt_engine(query_string: str, connection_string: str):
    """
    :param query_string: The raw query string to execute
    :param connection: Connection string formatted for use by PYODBC
    :return: A pandas DataFrame
    """
    connection = pyodbc.connect(connection_string)
    try:
        return pd.read_sql_query(query_string, connection)
    except Exception as e:
        print(e)
    finally:
        connection.close()

sql_root = pathlib.Path(r'C:\Users\david.smit\PycharmProjects\jinjaql\jinjaql\tests\queries')

snaql = JinJAQL(sql_root, engine=nwt_engine, cache=True)

gkn_queries = snaql.load_queries('GKN_query.sql')
context = {
    'database':'C1_RDM',
    'station':'View_Station440',
    'top':100,
}

def test_query():
    gkn_queries.top_ten(**context)

total_time = timeit.timeit(test_query, number=5)
print(total_time)


from jinjaql.factory import JinJAQL
import pandas as pd
import pyodbc
import functools
import pathlib

def nwt_engine(query_string: str, connection_string: str):
    """
    :param query_string: The raw query string to execute
    :param connection: Connection string formatted for use by PYODBC
    :return: A pandas DataFrame
    """
    connection = pyodbc.connect(connection_string)
    try:
        return pd.read_sql_query(query_string, connection)
    except Exception as e:
        print(e)
    finally:
        connection.close()


factory = JinJAQL(folder_path=pathlib.Path(''), engine=nwt_engine, cache=functools.lru_cache)
query = factory.load_queries('GKN_test.sql')

print(query.station_data(database='C1_RDM',station='View_Station440', ))
print(query.station_data(database='C1_RDM',station='View_Station440', ))
print(query.sta440())
print(query.sta440())


# coding: utf-8
import os
import sys
from shutil import rmtree
from setuptools import setup, find_packages, Command

# TODO Check into GitHUB actions to run the tests on pull request.

DESCRIPTION = 'SNAQL (Templated SQL) with the ability to pull data.'
HERE_PATH = os.path.dirname(os.path.abspath(__file__))
VERSION = '0.2.0'


try:
    with open(os.path.join(HERE_PATH, 'README.md')) as f:
        long_description = '\n' + f.read()
except IOError:
    long_description = DESCRIPTION

setup(
    name='jinjaql',
    version=VERSION,
    author='Richard Foley and David Smit (based on the work of Roman Zaiev)',
    author_email='david.d.smit@gmail.com',
    packages=find_packages(),
    license='MIT',
    url='https://github.com/RichFoley/jinjaql',
    description='Transparant *QL usage without ORM',
    long_description=DESCRIPTION,
    long_description_content_type='text/markdown',
    include_package_data=True,
    install_requires=[
        'Jinja2>=2.9.5', # TODO Check if a different version needs to be pinned
        'schema>=0.6.5',
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    # cmdclass={
    #     'upload': UploadCommand,
    # },
    exclude_package_data={"": ["*GKN*"]}
)
